ConfigurationInfo class

Statistics about how long a given device configuration was active.

Returned by UsageStats.queryConfiguration.

Constructors

ConfigurationInfo({String? activationCount, String? totalTimeActive, String? configuration, String? lastTimeActive, String? firstTimeStamp, String? lastTimeStamp})
Creates a ConfigurationInfo. Usually constructed via ConfigurationInfo.fromMap.
ConfigurationInfo.fromMap(Map map)
Builds a ConfigurationInfo from a platform-channel map.
factory

Properties

activationCount String?
Number of times this configuration became active (string).
final
activationCountValue int?
activationCount parsed to an int, or null.
no setter
configuration String?
String representation of the Android Configuration.
final
firstTimeStamp String?
Beginning of the queried interval, as epoch milliseconds (string).
final
firstTimestampDate DateTime?
firstTimeStamp parsed to a DateTime, or null.
no setter
hashCode int
The hash code for this object.
no setterinherited
lastTimeActive String?
Last time this configuration was active, as epoch milliseconds (string).
final
lastTimeActiveDate DateTime?
lastTimeActive parsed to a DateTime, or null.
no setter
lastTimeStamp String?
End of the queried interval, as epoch milliseconds (string).
final
lastTimestampDate DateTime?
lastTimeStamp parsed to a DateTime, or null.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalTimeActive String?
Total time this configuration was active, in milliseconds (string).
final
totalTimeActiveMs int?
totalTimeActive parsed to an int (milliseconds), or null.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited