NetworkType enum

The transport to aggregate when querying network usage.

Inheritance
Available extensions

Values

all → const NetworkType

Wi-Fi plus mobile/cellular combined.

wifi → const NetworkType

Wi-Fi only.

mobile → const NetworkType

Mobile/cellular only.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int

Available on NetworkType, provided by the NetworkTypeExt extension

The platform-channel value for this NetworkType.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NetworkType>
A constant List of the values in this enum, in order of their declaration.